SDK
===

.. image:: https://img.shields.io/pypi/v/kits.svg
    :target: https://pypi.python.org/pypi/kits/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/wheel/kits.svg
    :target: https://pypi.python.org/pypi/kits/

.. image:: https://img.shields.io/pypi/pyversions/kits.svg
    :target: https://pypi.python.org/pypi/kits/

.. image:: https://img.shields.io/pypi/l/kits.svg
    :target: https://pypi.python.org/pypi/kits/



SDK.


Installing
----------

Install and update using `pip`_:

.. code-block:: text

    pip install -U kits



.. _pip: https://pip.pypa.io/en/stable/quickstart/
